@@ -21,6 +21,7 @@ class CollectionModel: MLBaseModel {
 
     var observable = Observable<MediaLibraryBaseModelObserver>()
 
+    var fileArrayLock = NSRecursiveLock()
     var files = [VLCMLMedia]()
 
     var cellType: BaseCollectionViewCell.Type {
@@ -43,6 +44,9 @@ class CollectionModel: MLBaseModel {
     }
 
     required init(mediaService: MediaLibraryService, mediaCollection: MediaCollectionModel) {
+        defer {
+            fileArrayLock.unlock()
+        }
         self.medialibrary = mediaService
         self.mediaCollection = mediaCollection
         self.sortModel = mediaCollection.sortModel() ?? self.sortModel
@@ -56,16 +60,26 @@ class CollectionModel: MLBaseModel {
         }
 
         self.sortModel.currentSort = sortingCriteria
+
+        fileArrayLock.lock()
         files = mediaCollection.files() ?? []
         medialibrary.observable.addObserver(self)
     }
 
     func append(_ item: VLCMLMedia) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files.append(item)
     }
 
     func delete(_ items: [MLType]) {
+        defer {
+            fileArrayLock.unlock()
+        }
         if let playlist = mediaCollection as? VLCMLPlaylist {
+            fileArrayLock.lock()
             for case let media in items {
                 if let index = files.firstIndex(of: media) {
                     playlist.removeMedia(fromPosition: UInt32(index))
@@ -75,19 +89,21 @@ class CollectionModel: MLBaseModel {
             do {
                 for case let media in items {
                     if let mainFile = media.mainFile() {
-                        try FileManager.default.removeItem(atPath: mainFile.mrl.path)
+                        mainFile.delete()
                     }
                 }
                 medialibrary.reload()
             }
-            catch let error as NSError {
-                assertionFailure("CollectionModel: Delete failed: \(error.localizedDescription)")
-            }
+            fileArrayLock.lock()
             filterFilesFromDeletion(of: items)
         }
     }
 
     func sort(by criteria: VLCMLSortingCriteria, desc: Bool) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files = mediaCollection.files(with: criteria, desc: desc) ?? []
         sortModel.currentSort = criteria
         sortModel.desc = desc
@@ -101,7 +117,11 @@ class CollectionModel: MLBaseModel {
 extension CollectionModel: MediaLibraryObserver {
     func medialibrary(_ medialibrary: MediaLibraryService,
                       didModifyPlaylistsWithIds playlistsIds: [NSNumber]) {
+        defer {
+            fileArrayLock.unlock()
+        }
         if mediaCollection is VLCMLPlaylist {
+            fileArrayLock.lock()
             files = mediaCollection.files() ?? []
             observable.observers.forEach() {
                 $0.value.observer?.mediaLibraryBaseModelReloadView()
@@ -110,6 +130,10 @@ extension CollectionModel: MediaLibraryObserver {
     }
 
     func medialibrary(_ medialibrary: MediaLibraryService, didModifyTracks tracks: [VLCMLMedia]) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files = mediaCollection.files() ?? []
         observable.observers.forEach() {
             $0.value.observer?.mediaLibraryBaseModelReloadView()
@@ -117,6 +141,10 @@ extension CollectionModel: MediaLibraryObserver {
     }
 
     func medialibrary(_ medialibrary: MediaLibraryService, didDeleteMediaWithIds ids: [NSNumber]) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files = mediaCollection.files() ?? []
         observable.observers.forEach() {
             $0.value.observer?.mediaLibraryBaseModelReloadView()
@@ -129,6 +157,10 @@ extension CollectionModel: MediaLibraryObserver {
         guard success else {
             return
         }
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files = mediaCollection.files() ?? []
         observable.observers.forEach() {
             $0.value.observer?.mediaLibraryBaseModelReloadView()
@@ -136,6 +168,10 @@ extension CollectionModel: MediaLibraryObserver {
     }
 
     func medialibraryDidStartRescan() {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files.removeAll()
     }
 }
